@@ -21,10 +21,11 @@
  */
 
 #include "mixer_mpris2.h"
+
 #include "core/mixer.h"
 #include "core/ControlManager.h"
-#include "core/GlobalConfig.h"
 #include "kmix_debug.h"
+#include "settings.h"
 
 #include <QDBusReply>
 #include <qvariant.h>
@@ -152,8 +153,7 @@ void Mixer_MPRIS2::volumeChanged(MPrisControl* mad, double newVolume)
 {
 	shared_ptr<MixDevice> md = m_mixDevices.get(mad->getId());
 	int volInt = newVolume *100;
-	if (GlobalConfig::instance().data.debugVolume)
-		qCDebug(KMIX_LOG) << "changed" << volInt;
+	if (Settings::debugVolume()) qCDebug(KMIX_LOG) << "changed" << volInt;
 	volumeChangedInternal(md, volInt);
 }
 
@@ -282,8 +282,8 @@ int Mixer_MPRIS2::addAllRunningPlayersAndInitHotplug()
 		return 1;
 	}
 
-	QString busDestination;
-	foreach ( busDestination , repl.value() )
+	const QStringList &replyValues = repl.value();
+	for (const QString &busDestination : qAsConst(replyValues))
 	{
 		if ( busDestination.startsWith(QLatin1String("org.mpris.MediaPlayer2")) )
 		{
@@ -330,7 +330,6 @@ void Mixer_MPRIS2::addMprisControlAsync(QString busDestination)
 	mad->playerIfc = qdbiPlayer;
 	controls.insert(id, mad);
 
-
 	/*
 	 * WTF: - asyncCall("Get", arg)                          : returns an error message (see below)
 	 *      - asyncCallWithArgumentList("Get", arg)          : returns an error message (see below)
@@ -372,6 +371,8 @@ static QString getIconNameFromPlayerId(const QString &id)
 	// Surprisingly...
 	if (id.startsWith(QLatin1String("chrome"))) return ("chrome-browser");
 	if (id.startsWith(QLatin1String("chromium"))) return ("chromium-browser");
+	// Uses QtWebEngine which is based on Chromium, so as above...
+	if (id.startsWith(QLatin1String("akregator"))) return ("akregator");
 
 	return (QString());				// no application known
 }
