@@ -38,10 +38,11 @@
 #include "gui/kmixtoolbox.h"
 #include "gui/mixdevicewidget.h"
 #include "gui/mdwslider.h"
+#include "gui/mdwenum.h"
 #include "core/ControlManager.h"
-#include "core/GlobalConfig.h"
 #include "core/mixer.h"
 #include "core/mixertoolbox.h"
+#include "settings.h"
 
 
 /**
@@ -100,8 +101,8 @@ QPushButton* ViewBase::createConfigureViewButton()
 
 void ViewBase::updateGuiOptions()
 {
-    setTicks(GlobalConfig::instance().data.showTicks);
-    setLabels(GlobalConfig::instance().data.showLabels);
+    setTicks(Settings::showTicks());
+    setLabels(Settings::showLabels());
     updateMediaPlaybackIcons();
 }
 
@@ -153,7 +154,7 @@ void ViewBase::createDeviceWidgets()
     qCDebug(KMIX_LOG) << id() << "orientation" << _orientation;
 
     initLayout();
-    foreach (const shared_ptr<MixDevice> md, _mixSet)
+    for (const shared_ptr<MixDevice> md : qAsConst(_mixSet))
     {
         QWidget *mdw = add(md);				// a) Let the implementation do its work
         _mdws.append(mdw);				// b) Add it to the local list
@@ -171,6 +172,57 @@ void ViewBase::createDeviceWidgets()
     if (wasVisible) show();				// show again if originally visible
 }
 
+
+void ViewBase::adjustControlsLayout()
+{
+	// Adjust the view layout by setting the extent of all the control labels
+	// to allow space for the largest.  The extent of a control's label is
+	// found from its labelExtentHint() virtual function (which takes account
+	// of the control layout direction), and is then set by its setLabelExtent()
+	// virtual function.
+
+	// The maximum extent is calculated and set separately for sliders and
+	// for switches (enums).
+	int labelExtentSliders = 0;
+	int labelExtentSwitches = 0;
+
+	const int num = mixDeviceCount();
+
+	// Pass 1: Find the maximum extent of all applicable controls
+	for (int i = 0; i<num; ++i)
+	{
+		const QWidget *w = mixDeviceAt(i);
+		Q_ASSERT(w!=nullptr);
+		if (!w->isVisibleTo(this)) continue;	// not currently visible
+
+		const MDWSlider *mdws = qobject_cast<const MDWSlider *>(w);
+		if (mdws!=nullptr) labelExtentSliders = qMax(labelExtentSliders, mdws->labelExtentHint());
+
+		const MDWEnum *mdwe = qobject_cast<const MDWEnum *>(w);
+		if (mdwe!=nullptr) labelExtentSwitches = qMax(labelExtentSwitches, mdwe->labelExtentHint());
+	}
+
+	// Pass 2: Set the maximum extent of all applicable controls
+	for (int i = 0; i<num; ++i)
+	{
+		QWidget *w = mixDeviceAt(i);
+		Q_ASSERT(w!=nullptr);
+		if (!w->isVisibleTo(this)) continue;	// not currently visible
+
+		MDWSlider *mdws = qobject_cast<MDWSlider *>(w);
+		if (mdws!=nullptr && labelExtentSliders>0) mdws->setLabelExtent(labelExtentSliders);
+
+		MDWEnum *mdwe = qobject_cast<MDWEnum *>(w);
+		if (mdwe!=nullptr && labelExtentSwitches>0) mdwe->setLabelExtent(labelExtentSwitches);
+	}
+
+	// An old comment in ViewSliders::configurationUpdate() said
+	// that this was necessary for KDE3.  Not sure if it is still
+	// required two generations later.
+	layout()->activate();
+}
+
+
 /**
  * Called when a specific control is to be shown or hidden. At the moment it is only called via
  * the "hide" action in the MDW context menu.
@@ -182,8 +234,8 @@ void ViewBase::guiVisibilitySlot(MixDeviceWidget* mdw, bool enable)
 {
 	MixDevice* md = mdw->mixDevice().get();
 	qCDebug(KMIX_LOG) << "Change " << md->id() << " to visible=" << enable;
-	ProfControl* pctl = findMdw(md->id());
-	if (pctl == 0)
+	ProfControl *pctl = findMdw(md->id());
+	if (pctl==nullptr)
 	{
 		qCWarning(KMIX_LOG) << "MixDevice not found, and cannot be hidden, id=" << md->id();
 		return; // Ignore
@@ -256,23 +308,21 @@ void ViewBase::refreshVolumeLevels()
  */
 bool ViewBase::isDynamic() const
 {
-  foreach (Mixer* mixer , _mixers )
-  {
-    if ( mixer->isDynamic() )
-      return true;
-  }
-  return false;
+	for (const Mixer *mixer : qAsConst(_mixers))
+	{
+		if (mixer->isDynamic()) return true;
+	}
+	return false;
 }
 
 bool ViewBase::pulseaudioPresent() const
 {
 	// We do not use Mixer::pulseaudioPresent(), as we are only interested in Mixer instances contained in this View.
-  foreach (Mixer* mixer , _mixers )
-  {
-	  if ( mixer->getDriverName() == "PulseAudio" )
-		  return true;
-  }
-  return false;
+	for (const Mixer *mixer : qAsConst(_mixers))
+	{
+		if ( mixer->getDriverName() == "PulseAudio" ) return true;
+	}
+	return false;
 }
 
 
@@ -292,7 +342,7 @@ void ViewBase::resetMdws()
 int ViewBase::visibleControls() const
 {
 	int visibleCount = 0;
-	foreach (QWidget* qw, _mdws)
+	for (const QWidget *qw : qAsConst(_mdws))
 	{
 		if (qw->isVisible())
 			++ visibleCount;
@@ -348,7 +398,7 @@ void ViewBase::load(const KConfig *config)
 	{
 		const GuiVisibility guiCompl = guiVisibilities[i];
 		bool atLeastOneControlIsShown = false;
-		foreach(QWidget *qmdw, view->_mdws)
+		for (QWidget *qmdw : qAsConst(view->_mdws))
 		{
 			MixDeviceWidget *mdw = qobject_cast<MixDeviceWidget *>(qmdw);
 			if (mdw!=nullptr)
@@ -407,7 +457,7 @@ void ViewBase::setGuiLevel(GuiVisibility guiLevel)
  */
 ProfControl *ViewBase::findMdw(const QString& mdwId, GuiVisibility visibility) const
 {
-	foreach ( ProfControl* pControl, guiProfile()->getControls() )
+	for (ProfControl *pControl : qAsConst(guiProfile()->getControls()))
 	{
 		QRegExp idRegExp(pControl->id());
 		if ( mdwId.contains(idRegExp) )
